#!/usr/bin/perl -w
use lib "lib";
use ExtUtils::MakeMaker;
use POSIX;
use strict;

##################################################
#
#  As we want to install non standard directories, we need
#  to add the following.  This overwrites the install method
#  in the make command to have out ext_install method
#  called.  We then add the directories that we want to install
#
##################################################

my $arch = [uname]->[4];


my $extras;
if($arch =~ /ppc/) {
  $extras = "\tsamples/ppc \$(PREFIX)/samples \\\n\tsamples/ppcbin \$(PREFIX)/bin \\";
} elsif($arch =~ /(i386|i486|i586|i686)/) {
  $extras = "\tsamples/i386 \$(PREFIX)/samples \\";
}


sub MY::postamble {
  "
install :: all pure_install doc_install ext_install

ext_install::
\t\@\$(MOD_INSTALL) \\
\ttemplates \$(PREFIX)/templates \\
\tshare \$(PREFIX)/share \\
\tsamples/noarch \$(PREFIX)/samples \\
$extras

rpm:: dist
\trpm -tb lui-\$(VERSION).tar.gz

";
} 

# See lib/ExtUtils/MakeMaker.pm for details of how to influence
# the contents of the Makefile that is written.
WriteMakefile(
	      'VERSION' => '1.12.2',
	      'NAME'	=> 'lui',
	      'macro'  => {
			   MAN1EXT => '1',
			   INSTALLSITEMAN1DIR => '/usr/share/man/man1',
			   INSTALLSITEMAN3DIR => '/usr/share/man/man3',
			   INSTALLMAN1DIR => '/usr/share/man/man1',
			   INSTALLMAN3DIR => '/usr/share/man/man3',
			   SITEPREFIX => '$(PREFIX)',
			  },
	      'PREFIX'    => '/usr/local/$(NAME)-$(VERSION)',
	      'INSTALLSITELIB' => '$(PREFIX)/lib',
	      'SITEARCHEXP' => '$(PREFIX)',
	      'INST_HTMLLIBDIR' => 'doc',
	      'INSTALLHTMLSITELIBDIR' => '$(PREFIX)/doc',
	      'EXE_FILES' => [qw(bin/allimr
				 bin/delete_bootp_entry 
				 bin/dellimr 
				 bin/lslimg
				 bin/mkdskp
				 bin/mklimm  
				 bin/unallimr
				 bin/chlimmod
				 bin/dellimg
				 bin/gendiskres
				 bin/lslimm
				 bin/mklimcs
				 bin/mklimr
				 bin/clone
				 bin/dellimm
				 bin/glui
				 bin/lslimr
				 bin/mklimg
				)],
              'MAN1PODS' =>  {'samples/noarch/mkluikernel' => '$(INST_MAN1DIR)/mkluikernel.$(MAN1EXT)',
                              'bin/allimr' => '$(INST_MAN1DIR)/allimr.$(MAN1EXT)',
                              'bin/delete_bootp_entry' => '$(INST_MAN1DIR)/delete_bootp_entry.$(MAN1EXT)',
                              'bin/dellimr' => '$(INST_MAN1DIR)/dellimr.$(MAN1EXT)',
                              'bin/lslimg' => '$(INST_MAN1DIR)/lslimg.$(MAN1EXT)',
                              'bin/mkdskp' => '$(INST_MAN1DIR)/mkdskp.$(MAN1EXT)',
                              'bin/mklimm' => '$(INST_MAN1DIR)/mklimm.$(MAN1EXT)',
                              'bin/unallimr' => '$(INST_MAN1DIR)/unallimr.$(MAN1EXT)',
                              'bin/chlimmod' => '$(INST_MAN1DIR)/chlimmod.$(MAN1EXT)',
                              'bin/dellimg' => '$(INST_MAN1DIR)/dellimg.$(MAN1EXT)',
                              'bin/gendiskres' => '$(INST_MAN1DIR)/gendiskres.$(MAN1EXT)',
                              'bin/lslimm' => '$(INST_MAN1DIR)/lslimm.$(MAN1EXT)',
                              'bin/mklimcs' => '$(INST_MAN1DIR)/mklimcs.$(MAN1EXT)',
                              'bin/mklimr' => '$(INST_MAN1DIR)/mklimr.$(MAN1EXT)',
                              'bin/clone' => '$(INST_MAN1DIR)/clone.$(MAN1EXT)',
                              'bin/dellimm' => '$(INST_MAN1DIR)/dellimm.$(MAN1EXT)',
                              'bin/glui' => '$(INST_MAN1DIR)/glui.$(MAN1EXT)',
                              'bin/lslimr' => '$(INST_MAN1DIR)/lslimr.$(MAN1EXT)',
                              'bin/mklimg' => '$(INST_MAN1DIR)/mklimg.$(MAN1EXT)',
                             },
	      'PREREQ_PM' => { 'Tk' => 1 },
	      'LIBS'	=> [''],   # e.g., '-lm' 
	      'DEFINE'	=> '',     # e.g., '-DHAVE_SOMETHING' 
	      'INC'	=> '',     # e.g., '-I/usr/include/other'
	      );

