#!/usr/bin/perl
#$Header: /usr/cvs/lui/lui/lib/LuiMisc.pm,v 1.1.1.1 2001/02/19 16:19:49 sdague Exp $

# Copyright (c) 2000, International Business Machines
#
# This software may be used and distributed according to the terms
# of the GNU Public License, incorporated herein by reference.
#
# The entire text of the GNU Public License is included in this
# package in the COPYING file; or can be found online at:
# http://www.Linux.org/info.gnu.html
#
# Authors: Norm Nott
#             ...
#####################################################################
#                                                                   #
# Module:  LuiMisc                                                  #
#                                                                   #
# Description:                                                      #
#                                                                   #
# Subroutines:                                                      #
#  parse_cmd_line                                                   #
#                                                                   #
# Notes:                                                            #
#                                                                   #
#####################################################################

package LuiMisc;

use FindBin qw($Bin);
use lib "$Bin";

use vars qw(@ISA @EXPORT @EXPORT_OK);
use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw($TRUE
            $FALSE 
            $NOK 
            $OK
            %option
            %match_attrs
            %set_attrs
            %list_attrs
            new_set_disk
);

use Getopt::Std;

#-------------------------------------------------------------------
#    Global Definitions
#-------------------------------------------------------------------

$NOK=1;
$OK=0;
$TRUE=1;
$FALSE=0;

# hashes populated by the command parsing subroutine
%option;          # - hash flags and values
%match_attrs;     # - hash of attr==value pairs (used for selecting)
%set_attrs;       # - set of attr=value pairs (used for setting)
%list_attrs;      # - remaining operands

#--------------------------------------------------------------------#
# Subroutines                                                        #
#---------------------------------------#----------------------------#

#####################################################################
#                                                                   #
# Subroutine:   parse_cmd_line                                      #
#                                                                   #
# Description:  Parse the command line flags and operands.          #
#                                                                   #
# Inputs:   List of flags using the same syntax as getopts().       #
#                                                                   #
# Outputs:                                                          #
#   %options  -  hash of flags and values, from getopts()           #
#   %match_attrs - hash of attr==value pairs (used for selecting)   #
#   %set_attrs   - set of attr=value pairs (used for setting)       #
#   %list_attrs  - remaining operands                               #
#                                                                   #
# Return Values:                                                    #
#                  NOK  - not successful  (1)                       #
#                   OK  - successful  (0)                           #
#                                                                   #
#####################################################################
sub parse_cmd_line {

    local ($flag_list) = @_;
    %option=();
    %match_attrs=();
    %set_attrs=();
    %list_attrs=();

    # use getopts to put the flags in the option hash
    if(!&getopts('\''.$flag_list.'\'', \%option) ) {
        print "parse_cmd_line(): Error with call to getopts().\n";
        return $NOK;
    }

    # now put any operands in hashes
    @operands = @ARGV;
    while ($operands[0]) {
        if ( $operands[0] =~ /^(\w+)==(.*)/ ) {   # match these attrs
            $match_attrs{$1} = $2;
        } elsif ( $operands[0] =~ /^(\w+)=(.*)/ ) {  # set these attrs
            $set_attrs{$1} = $2;
        } else {                                  # list these attrs
            $list_attrs{$operands[0]} = '';
        }
        shift(@operands);
    }

    return $OK;

} # End parse_cmd_line


# ##################################################################

1;
